@@ -72,7 +72,7 @@ class TestProbeChaos(unittest.TestCase):
 
         self.assertGreater(
             ProbeChaos(
-                """hishamkoc@yahoo.com ุชุฑุฌูููุฉ ููุดูููุงู ุงููููููููุงูRadoZ ุชูููุนููููุฏูููู ุงููููุชูููููููููููููุช ููููู ูููุจููู""").ratio,
+                """hishamkoc@yahoo.com ุชุฑุฌูููุฉ ููุดูููุงู ุงููููููููุงูRadoZ ุชูููุนููููุฏูููู ุงููููุชูููููููููููููุช ููููู ูููุจููู""", giveup_threshold=0.5).ratio,
             0.4
         )
 
